biosimulators_utils.viz package — BioSimulators utils 0.1.154 documentation

# biosimulators_utils.viz package

## Subpackages

- biosimulators_utils.viz.vega package
  - Subpackages
    - biosimulators_utils.viz.vega.escher package
      - Submodules
      - biosimulators_utils.viz.vega.escher.core module
    - biosimulators_utils.viz.vega.ginml package
      - Submodules
      - biosimulators_utils.viz.vega.ginml.core module
    - biosimulators_utils.viz.vega.sbgn package
      - Submodules
      - biosimulators_utils.viz.vega.sbgn.core module
  - Submodules
  - biosimulators_utils.viz.vega.utils module

## Submodules

## biosimulators_utils.viz.data_model module

Data model for plots

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2020-12-06

Copyright

  2020, Center for Reproducible Biomedical Modeling

License

  MIT

class biosimulators_utils.viz.data_model.VizFormat(value)

  Bases: `str`, `enum.Enum`

  Format of a report

  jpg = 'jpg'
  pdf = 'pdf'
  png = 'png'
  svg = 'svg'

## biosimulators_utils.viz.io module

Methods for generating SED plots

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2020-12-23

Copyright

  2020, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.viz.io.write_plot_2d(plot, data_generator_results, base_path, rel_path, format=VizFormat.pdf, style='seaborn-paper')

  Generate a 2D plot

  Parameters

    - plot (`Plot2D`) – description of plot

    - data_generator_results (`DataGeneratorResults`) – results of data generators

    - base_path (`str`) – base path to save plot

    - rel_path (`str`) – path to save results relative to `base_path`

    - format (`VizFormat`, optional) – format

    - style (`str`, optional) – matplotlib style

biosimulators_utils.viz.io.write_plot_3d(plot, data_generator_results, base_path, rel_path, format=VizFormat.pdf, style='seaborn-paper', colormaps=[<matplotlib.colors.ListedColormap object>, <matplotlib.colors.ListedColormap object>, <matplotlib.colors.ListedColormap object>, <matplotlib.colors.ListedColormap object>, <matplotlib.colors.ListedColormap object>])

  Generate a 3D plot

  Parameters

    - plot (`Plot3D`) – description of plot

    - data_generator_results (`DataGeneratorResults`) – results of data generators

    - base_path (`str`) – base path to save plot

    - rel_path (`str`) – path to save results relative to `base_path`

    - format (`VizFormat`, optional) – format

    - style (`str`, optional) – matplotlib style

    - colormaps (`list` of `matplotlib.colors.LinearSegmentedColormap`, optional) – colormaps

## biosimulators_utils.viz.utils module

Utilities for visualizations

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-07-22

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.viz.utils.cubic_bezier_angle(points, t)

  Get the angle of a point along a cubic bezier curve

  Parameters

    - points (`list` of `list` of `float`) – control points

    - t (`float`) – position along the curve [0, 1]

  Returns

    angle of the curve at point `t`

  Return type

    `float`

biosimulators_utils.viz.utils.cubic_bezier_point(points, t)

  Get the coordinate of a point along a cubic bezier curve

  Parameters

    - points (`list` of `list` of `float`) – control points

    - t (`float`) – position along the curve [0, 1]

  Returns

    position of the curve at point `t`

  Return type

    `tuple` of `float`

## biosimulators_utils.viz.warnings module

Warnings for plots

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-01-20

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

exception biosimulators_utils.viz.warnings.IllogicalVizWarning

  Bases: `biosimulators_utils.warnings.BioSimulatorsWarning`

  Warning that a plot is may be illogical (e.g., has mixed axes or scales)